//////////////////////////////////////////////////////////////////////////////
// Filename:          D:\pc-colt\d\JOB\SUZAKU_SE\fpga\8_1\ddl\20060623/drivers/opb_sil00_v1_01_a/src/opb_sil00.h
// Version:           1.01.a
// Description:       opb_sil00 Driver Header File
// Date:              Tue Aug 08 13:37:39 2006 (by Create and Import Peripheral Wizard)
//////////////////////////////////////////////////////////////////////////////

#ifndef OPB_SIL00_H
#define OPB_SIL00_H

/***************************** Include Files *******************************/

#include "xbasic_types.h"
#include "xstatus.h"
#include "xio.h"

/************************** Constant Definitions ***************************/


/**
 * User Logic Slave Space Offsets
 * -- SLAVE_REG0 : user logic slave module register 0
 * -- SLAVE_REG1 : user logic slave module register 1
 * -- SLAVE_REG2 : user logic slave module register 2
 * -- SLAVE_REG3 : user logic slave module register 3
 * -- SLAVE_REG4 : user logic slave module register 4
 * -- SLAVE_REG5 : user logic slave module register 5
 */
#define OPB_SIL00_USER_SLAVE_SPACE_OFFSET (0x00000000)
#define OPB_SIL00_SLAVE_REG0_OFFSET (OPB_SIL00_USER_SLAVE_SPACE_OFFSET + 0x00000000)
#define OPB_SIL00_SLAVE_REG1_OFFSET (OPB_SIL00_USER_SLAVE_SPACE_OFFSET + 0x00000001)
#define OPB_SIL00_SLAVE_REG2_OFFSET (OPB_SIL00_USER_SLAVE_SPACE_OFFSET + 0x00000002)
#define OPB_SIL00_SLAVE_REG3_OFFSET (OPB_SIL00_USER_SLAVE_SPACE_OFFSET + 0x00000003)
#define OPB_SIL00_SLAVE_REG4_OFFSET (OPB_SIL00_USER_SLAVE_SPACE_OFFSET + 0x00000004)
#define OPB_SIL00_SLAVE_REG5_OFFSET (OPB_SIL00_USER_SLAVE_SPACE_OFFSET + 0x00000005)

/**
 * IPIF Interrupt Controller Space Offsets
 * -- INTR_DISR  : device (ipif) interrupt status register
 * -- INTR_DIPR  : device (ipif) interrupt pending register
 * -- INTR_DIER  : device (ipif) interrupt enable register
 * -- INTR_DIIR  : device (ipif) interrupt id (priority encoder) register
 * -- INTR_DGIER : device (ipif) global interrupt enable register
 * -- INTR_ISR   : ip (user logic) interrupt status register
 * -- INTR_IER   : ip (user logic) interrupt enable register
 */
#define OPB_SIL00_IPIF_INTR_SPACE_OFFSET (0x00000100)
#define OPB_SIL00_INTR_DISR_OFFSET (OPB_SIL00_IPIF_INTR_SPACE_OFFSET + 0x00000000)
#define OPB_SIL00_INTR_DIPR_OFFSET (OPB_SIL00_IPIF_INTR_SPACE_OFFSET + 0x00000004)
#define OPB_SIL00_INTR_DIER_OFFSET (OPB_SIL00_IPIF_INTR_SPACE_OFFSET + 0x00000008)
#define OPB_SIL00_INTR_DIIR_OFFSET (OPB_SIL00_IPIF_INTR_SPACE_OFFSET + 0x00000018)
#define OPB_SIL00_INTR_DGIER_OFFSET (OPB_SIL00_IPIF_INTR_SPACE_OFFSET + 0x0000001C)
#define OPB_SIL00_INTR_ISR_OFFSET (OPB_SIL00_IPIF_INTR_SPACE_OFFSET + 0x00000020)
#define OPB_SIL00_INTR_IER_OFFSET (OPB_SIL00_IPIF_INTR_SPACE_OFFSET + 0x00000028)

/**
 * IPIF Interrupt Controller Masks
 * -- INTR_TERR_MASK : transaction error
 * -- INTR_DPTO_MASK : data phase time-out
 * -- INTR_IPIR_MASK : ip interrupt requeset
 * -- INTR_DMA0_MASK : dma channel 0 interrupt request
 * -- INTR_DMA1_MASK : dma channel 1 interrupt request
 * -- INTR_RFDL_MASK : read packet fifo deadlock interrupt request
 * -- INTR_WFDL_MASK : write packet fifo deadlock interrupt request
 * -- INTR_IID_MASK  : interrupt id
 * -- INTR_GIE_MASK  : global interrupt enable
 * -- INTR_NOPEND    : the DIPR has no pending interrupts
 */
#define INTR_TERR_MASK (0x00000001UL)
#define INTR_DPTO_MASK (0x00000002UL)
#define INTR_IPIR_MASK (0x00000004UL)
#define INTR_DMA0_MASK (0x00000008UL)
#define INTR_DMA1_MASK (0x00000010UL)
#define INTR_RFDL_MASK (0x00000020UL)
#define INTR_WFDL_MASK (0x00000040UL)
#define INTR_IID_MASK (0x000000FFUL)
#define INTR_GIE_MASK (0x80000000UL)
#define INTR_NOPEND (0x80)

/***************** Macros (Inline Functions) Definitions *******************/

/**
 *
 * Write a value to a OPB_SIL00 register. A 32 bit write is performed.
 * If the component is implemented in a smaller width, only the least
 * significant data is written.
 *
 * @param   BaseAddress is the base address of the OPB_SIL00 device.
 * @param   RegOffset is the register offset from the base to write to.
 * @param   Data is the data written to the register.
 *
 * @return  None.
 *
 * @note    None.
 *
 * C-style signature:
 * 	void OPB_SIL00_mWriteReg(Xuint32 BaseAddress, unsigned RegOffset, Xuint32 Data)
 *
 */
#define OPB_SIL00_mWriteReg(BaseAddress, RegOffset, Data) \
 	XIo_Out32((BaseAddress) + (RegOffset), (Xuint32)(Data))

/**
 *
 * Read a value from a OPB_SIL00 register. A 32 bit read is performed.
 * If the component is implemented in a smaller width, only the least
 * significant data is read from the register. The most significant data
 * will be read as 0.
 *
 * @param   BaseAddress is the base address of the OPB_SIL00 device.
 * @param   RegOffset is the register offset from the base to write to.
 *
 * @return  Data is the data from the register.
 *
 * @note    None.
 *
 * C-style signature:
 * 	Xuint32 OPB_SIL00_mReadReg(Xuint32 BaseAddress, unsigned RegOffset)
 *
 */
#define OPB_SIL00_mReadReg(BaseAddress, RegOffset) \
 	XIo_In32((BaseAddress) + (RegOffset))


/**
 *
 * Write/Read value to/from OPB_SIL00 user logic slave registers.
 *
 * @param   BaseAddress is the base address of the OPB_SIL00 device.
 * @param   Value is the data written to the register.
 *
 * @return  Data is the data from the user logic slave register.
 *
 * @note    None.
 *
 * C-style signature:
 * 	Xuint8 OPB_SIL00_mReadSlaveRegn(Xuint32 BaseAddress)
 *
 */
#define OPB_SIL00_mWriteSlaveReg0(BaseAddress, Value) \
 	XIo_Out8((BaseAddress) + (OPB_SIL00_SLAVE_REG0_OFFSET), (Xuint8)(Value))
#define OPB_SIL00_mWriteSlaveReg1(BaseAddress, Value) \
 	XIo_Out8((BaseAddress) + (OPB_SIL00_SLAVE_REG1_OFFSET), (Xuint8)(Value))
#define OPB_SIL00_mWriteSlaveReg2(BaseAddress, Value) \
 	XIo_Out8((BaseAddress) + (OPB_SIL00_SLAVE_REG2_OFFSET), (Xuint8)(Value))
#define OPB_SIL00_mWriteSlaveReg3(BaseAddress, Value) \
 	XIo_Out8((BaseAddress) + (OPB_SIL00_SLAVE_REG3_OFFSET), (Xuint8)(Value))
#define OPB_SIL00_mWriteSlaveReg4(BaseAddress, Value) \
 	XIo_Out8((BaseAddress) + (OPB_SIL00_SLAVE_REG4_OFFSET), (Xuint8)(Value))
#define OPB_SIL00_mWriteSlaveReg5(BaseAddress, Value) \
 	XIo_Out8((BaseAddress) + (OPB_SIL00_SLAVE_REG5_OFFSET), (Xuint8)(Value))

#define OPB_SIL00_mReadSlaveReg0(BaseAddress) \
 	XIo_In8((BaseAddress) + (OPB_SIL00_SLAVE_REG0_OFFSET))
#define OPB_SIL00_mReadSlaveReg1(BaseAddress) \
 	XIo_In8((BaseAddress) + (OPB_SIL00_SLAVE_REG1_OFFSET))
#define OPB_SIL00_mReadSlaveReg2(BaseAddress) \
 	XIo_In8((BaseAddress) + (OPB_SIL00_SLAVE_REG2_OFFSET))
#define OPB_SIL00_mReadSlaveReg3(BaseAddress) \
 	XIo_In8((BaseAddress) + (OPB_SIL00_SLAVE_REG3_OFFSET))
#define OPB_SIL00_mReadSlaveReg4(BaseAddress) \
 	XIo_In8((BaseAddress) + (OPB_SIL00_SLAVE_REG4_OFFSET))
#define OPB_SIL00_mReadSlaveReg5(BaseAddress) \
 	XIo_In8((BaseAddress) + (OPB_SIL00_SLAVE_REG5_OFFSET))

/************************** Function Prototypes ****************************/


/**
 *
 * Enable all possible interrupts from OPB_SIL00 device.
 *
 * @param   baseaddr_p is the base address of the OPB_SIL00 device.
 *
 * @return  None.
 *
 * @note    None.
 *
 */
void OPB_SIL00_EnableInterrupt(void * baseaddr_p);

/**
 *
 * Example interrupt controller handler.
 *
 * @param   baseaddr_p is the base address of the OPB_SIL00 device.
 *
 * @return  None.
 *
 * @note    None.
 *
 */
void OPB_SIL00_Intr_DefaultHandler(void * baseaddr_p);

/**
 *
 * Run a self-test on the driver/device. Note this may be a destructive test if
 * resets of the device are performed.
 *
 * If the hardware system is not built correctly, this function may never
 * return to the caller.
 *
 * @param   baseaddr_p is the base address of the OPB_SIL00 instance to be worked on.
 *
 * @return
 *
 *    - XST_SUCCESS   if all self-test code passed
 *    - XST_FAILURE   if any self-test code failed
 *
 * @note    Caching must be turned off for this function to work.
 * @note    Self test may fail if data memory and device are not on the same bus.
 *
 */
XStatus OPB_SIL00_SelfTest(void * baseaddr_p);

#endif // OPB_SIL00_H
